@@ -33,9 +33,90 @@ class ThemeSwitchAIO(html.Div):
 
     def __init__(
         self,
-        themes=[dbc.themes.CYBORG, dbc.themes.BOOTSTRAP],
-        icons={"left": "fa fa-moon", "right": "fa fa-sun"},
+        themes=None,
+        icons=None,
         switch_props={},
+
+#
+# from dash import Dash, dcc, html, Input, Output
+# import plotly.express as px
+# import dash_bootstrap_components as dbc
+# from dash_bootstrap_templates import ThemeSwitchAIO
+#
+# # select the Bootstrap stylesheets and figure templates for the theme toggle here:
+# template_theme1 = "flatly"
+# template_theme2 = "darkly"
+# url_theme1 = dbc.themes.FLATLY
+# url_theme2 = dbc.themes.DARKLY
+#
+# theme_toggle = ThemeSwitchAIO(
+#     aio_id="theme",
+#     themes=[url_theme2, url_theme1],
+#     icons={"left": "fa fa-sun", "right": "fa fa-moon"},
+# )
+#
+# dbc_css = (
+#     "https://cdn.jsdelivr.net/gh/AnnMarieW/dash-bootstrap-templates/dbc.min.css"
+# )
+# app = Dash(__name__, external_stylesheets=[url_theme2, dbc_css])
+#
+# df = px.data.gapminder()
+# header = html.H4("ThemeSwitchAIO Demo", className="bg-primary text-white p-4 mb-2")
+# buttons = html.Div(
+#     [
+#         dbc.Button("Primary", color="primary"),
+#         dbc.Button("Secondary", color="secondary"),
+#         dbc.Button("Success", color="success"),
+#         dbc.Button("Warning", color="warning"),
+#         dbc.Button("Danger", color="danger"),
+#         dbc.Button("Info", color="info"),
+#         dbc.Button("Light", color="light"),
+#         dbc.Button("Dark", color="dark"),
+#         dbc.Button("Link", color="link"),
+#     ],
+#     className="m-4",
+# )
+# graph = html.Div(dcc.Graph(id="graph"), className="m-4")
+#
+# app.layout = dbc.Container(
+#     dbc.Row(
+#         [
+#             dbc.Col(
+#                 [
+#                     header,
+#                     theme_toggle,
+#                     buttons,
+#                     graph,
+#                 ]
+#             )
+#         ]
+#     ),
+#     className="m-4 dbc",
+#     fluid=True,
+# )
+#
+#
+# @app.callback(
+#     Output("graph", "figure"), Input(ThemeSwitchAIO.ids.switch("theme"), "value"),
+# )
+# def update_graph_theme(toggle):
+#     template = template_theme2 if toggle else template_theme1
+#     return px.scatter(
+#         df.query("year==2007"),
+#         x="gdpPercap",
+#         y="lifeExp",
+#         size="pop",
+#         color="continent",
+#         log_x=True,
+#         size_max=60,
+#         template=template,
+#         title="Gapminder 2007: '%s' theme" % template,
+#     )
+#
+#
+# if __name__ == "__main__":
+#     app.run_server(debug=True)
+
         aio_id=None,
     ):
         """ThemeSwitchAIO is an All-in-One component  composed  of a parent `html.Div` with
@@ -66,6 +147,11 @@ class ThemeSwitchAIO(html.Div):
         if aio_id is None:
             aio_id = str(uuid.uuid4())
 
+        if themes is None:
+            themes = [dbc.themes.CYBORG, dbc.themes.BOOTSTRAP]
+        if icons is None:
+            icons = {"left": "fa fa-moon", "right": "fa fa-sun"}
+
         switch_props = switch_props.copy()
         if "value" not in switch_props:
             switch_props["value"] = True
@@ -115,16 +201,16 @@ class ThemeSwitchAIO(html.Div):
     # even if there is nothing to update.
     #
     clientside_callback(
-        """       
-        function(switchUrls) {
-            console.log("initialize", switchUrls[0])
+        """
+        function(theme_switch, theme_urls) {            
+            var themeLink = theme_switch ? theme_urls[0] : theme_urls[1];
             let urls = [
-                "https://use.fontawesome.com/releases/v5.15.4/css/all.css",   
-                switchUrls[0]      
+                "https://use.fontawesome.com/releases/v5.15.4/css/all.css",
+                themeLink
             ];
-            for (const url of urls) {                
+            for (const url of urls) {
                 var link = document.createElement("link");
-            
+
                 link.type = "text/css";
                 link.rel = "stylesheet";
                 link.href = url;
@@ -134,5 +220,6 @@ class ThemeSwitchAIO(html.Div):
         }
         """,
         Output(ids.dummy_div(MATCH), "role"),
+        Input(ids.switch(MATCH), "value"),
         Input(ids.store(MATCH), "data"),
     )
